==> xtensor-0.24.0-h5362a0b_0.tar.bz2: Library/include/xtensor.hpp <==
#ifndef XTENSOR
#define XTENSOR

#include <xtensor/xaccessible.hpp>
#include <xtensor/xaccumulator.hpp>
#include <xtensor/xadapt.hpp>
#include <xtensor/xarray.hpp>
#include <xtensor/xassign.hpp>
#include <xtensor/xaxis_iterator.hpp>
#include <xtensor/xaxis_slice_iterator.hpp>
#include <xtensor/xbroadcast.hpp>
#include <xtensor/xbuffer_adaptor.hpp>
#include <xtensor/xbuilder.hpp>
#include <xtensor/xchunked_array.hpp>
#include <xtensor/xchunked_assign.hpp>
#include <xtensor/xchunked_view.hpp>
#include <xtensor/xcomplex.hpp>
#include <xtensor/xcontainer.hpp>
#include <xtensor/xcsv.hpp>
#include <xtensor/xdynamic_view.hpp>
#include <xtensor/xeval.hpp>
#include <xtensor/xexception.hpp>
#include <xtensor/xexpression.hpp>
#include <xtensor/xexpression_traits.hpp>
#include <xtensor/xfixed.hpp>
#include <xtensor/xfunction.hpp>
#include <xtensor/xfunctor_view.hpp>
#include <xtensor/xgenerator.hpp>
#include <xtensor/xhistogram.hpp>
#include <xtensor/xindex_view.hpp>
#include <xtensor/xinfo.hpp>
#include <xtensor/xio.hpp>
#include <xtensor/xiterable.hpp>
#include <xtensor/xiterator.hpp>
#include <xtensor/xlayout.hpp>
#include <xtensor/xmanipulation.hpp>
#include <xtensor/xmasked_view.hpp>
#include <xtensor/xmath.hpp>
#include <xtensor/xnoalias.hpp>
#include <xtensor/xnorm.hpp>
#include <xtensor/xoffset_view.hpp>
#include <xtensor/xoperation.hpp>
#include <xtensor/xoptional.hpp>
#include <xtensor/xoptional_assembly.hpp>
#include <xtensor/xoptional_assembly_base.hpp>
#include <xtensor/xoptional_assembly_storage.hpp>
#include <xtensor/xpad.hpp>
#include <xtensor/xrandom.hpp>
#include <xtensor/xreducer.hpp>
#include <xtensor/xrepeat.hpp>
#include <xtensor/xscalar.hpp>
#include <xtensor/xsemantic.hpp>
#include <xtensor/xset_operation.hpp>
#include <xtensor/xshape.hpp>
#include <xtensor/xslice.hpp>
#include <xtensor/xsort.hpp>
#include <xtensor/xstorage.hpp>
#include <xtensor/xstrided_view.hpp>
#include <xtensor/xstrided_view_base.hpp>
#include <xtensor/xstrides.hpp>
#include <xtensor/xtensor.hpp>
#include <xtensor/xtensor_config.hpp>
#include <xtensor/xtensor_forward.hpp>
#include <xtensor/xtensor_simd.hpp>
#include <xtensor/xutils.hpp>
#include <xtensor/xvectorize.hpp>
#include <xtensor/xview.hpp>
#include <xtensor/xview_utils.hpp>

#endif

==> xtensor-0.24.2-h5362a0b_0.tar.bz2: Library/include/xtensor.hpp <==
#ifndef XTENSOR
#define XTENSOR

#include <xtensor/xaccessible.hpp>
#include <xtensor/xaccumulator.hpp>
#include <xtensor/xadapt.hpp>
#include <xtensor/xarray.hpp>
#include <xtensor/xassign.hpp>
#include <xtensor/xaxis_iterator.hpp>
#include <xtensor/xaxis_slice_iterator.hpp>
#include <xtensor/xblockwise_reducer.hpp>
#include <xtensor/xblockwise_reducer_functors.hpp>
#include <xtensor/xbroadcast.hpp>
#include <xtensor/xbuffer_adaptor.hpp>
#include <xtensor/xbuilder.hpp>
#include <xtensor/xchunked_array.hpp>
#include <xtensor/xchunked_assign.hpp>
#include <xtensor/xchunked_view.hpp>
#include <xtensor/xcomplex.hpp>
#include <xtensor/xcontainer.hpp>
#include <xtensor/xcsv.hpp>
#include <xtensor/xdynamic_view.hpp>
#include <xtensor/xeval.hpp>
#include <xtensor/xexception.hpp>
#include <xtensor/xexpression.hpp>
#include <xtensor/xexpression_traits.hpp>
#include <xtensor/xfixed.hpp>
#include <xtensor/xfunction.hpp>
#include <xtensor/xfunctor_view.hpp>
#include <xtensor/xgenerator.hpp>
#include <xtensor/xhistogram.hpp>
#include <xtensor/xindex_view.hpp>
#include <xtensor/xinfo.hpp>
#include <xtensor/xio.hpp>
#include <xtensor/xiterable.hpp>
#include <xtensor/xiterator.hpp>
#include <xtensor/xlayout.hpp>
#include <xtensor/xmanipulation.hpp>
#include <xtensor/xmasked_view.hpp>
#include <xtensor/xmath.hpp>
#include <xtensor/xmultiindex_iterator.hpp>
#include <xtensor/xnoalias.hpp>
#include <xtensor/xnorm.hpp>
#include <xtensor/xoffset_view.hpp>
#include <xtensor/xoperation.hpp>
#include <xtensor/xoptional.hpp>
#include <xtensor/xoptional_assembly.hpp>
#include <xtensor/xoptional_assembly_base.hpp>
#include <xtensor/xoptional_assembly_storage.hpp>
#include <xtensor/xpad.hpp>
#include <xtensor/xrandom.hpp>
#include <xtensor/xreducer.hpp>
#include <xtensor/xrepeat.hpp>
#include <xtensor/xscalar.hpp>
#include <xtensor/xsemantic.hpp>
#include <xtensor/xset_operation.hpp>
#include <xtensor/xshape.hpp>
#include <xtensor/xslice.hpp>
#include <xtensor/xsort.hpp>
#include <xtensor/xstorage.hpp>
#include <xtensor/xstrided_view.hpp>
#include <xtensor/xstrided_view_base.hpp>
#include <xtensor/xstrides.hpp>
#include <xtensor/xtensor.hpp>
#include <xtensor/xtensor_config.hpp>
#include <xtensor/xtensor_forward.hpp>
#include <xtensor/xtensor_simd.hpp>
#include <xtensor/xutils.hpp>
#include <xtensor/xvectorize.hpp>
#include <xtensor/xview.hpp>
#include <xtensor/xview_utils.hpp>

#endif
